abacusai.app_user_group — AbacusAI documentation

# abacusai.app_user_group

## Classes

`AppUserGroup` | An app user group. This is used to determine which users have permissions for external chatbots.

## Module Contents

class abacusai.app_user_group.AppUserGroup(client, name=None, userGroupId=None, externalApplicationIds=None, invitedUserEmails=None, publicUserGroup=None, hasExternalApplicationReporting=None, isExternalServiceGroup=None, externalServiceGroupId=None, users={})

  Bases: `abacusai.return_class.AbstractApiClass`

  An app user group. This is used to determine which users have permissions for external chatbots.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the user group.

    - userGroupId (str) – The unique identifier of the user group.

    - externalApplicationIds (list[str]) – The ids of the external applications the group has access to.

    - invitedUserEmails (list[str]) – The emails of the users invited to the user group who have not yet accepted the invite.

    - publicUserGroup (bool) – Boolean flag whether the app user group is the public user group of the org or not.

    - hasExternalApplicationReporting (bool) – Whether users in the App User Group have permission to view all reports in their organization.

    - isExternalServiceGroup (bool) – Whether the App User Group corresponds to a user group that’s defined in an external service (i.e Microsft Active Directory or Okta) or not

    - externalServiceGroupId (str) – The identifier that corresponds to the app user group’s external service group representation

    - users (User) – The users in the user group.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict